#ifndef _URCU_CDS_H
#define _URCU_CDS_H

/*
 * urcu/cds.h
 *
 * Userspace RCU library - Concurrent Data Structures
 *
 * Copyright 2011 - Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include <urcu/hlist.h>
#include <urcu/list.h>
#include <urcu/rcuhlist.h>
#include <urcu/rculist.h>
#include <urcu/rculfqueue.h>
#include <urcu/rculfstack.h>
#include <urcu/rculfhash.h>
#include <urcu/wfqueue.h>
#include <urcu/wfcqueue.h>
#include <urcu/wfstack.h>
#include <urcu/lfstack.h>

#endif /* _URCU_CDS_H */
